pilas.actores.proyectil

Package pilas :: Package actores :: Module proyectil |
[hide private]
[frames] | no frames]

# Module proyectil

source code

Classes | [hide private]
| Misil Representa un misil que va en línea recta con aceleración.
| Bala Representa una bala que va en línea recta.
| Dinamita Representa un cartucho de dinamita.
| EstrellaNinja Representa una estrella ninja.

Variables | [hide private]
| __package__ = ``'``pilas.actores``'``